@@ -57,8 +57,8 @@ doo <- function(data, .f, ..., result = ".results."){
   .results <- data %>%
     nest() %>%
     dplyr::ungroup() %>%
-    mutate(data = map(data, droplevels)) %>%
-    mutate(data = map(data, .f, ...))
+    mutate(data = map(.data$data, droplevels)) %>%
+    mutate(data = map(.data$data, .f, ...))
   if(inherits(.results$data[[1]], c("data.frame", "tbl_df"))){
     # Suppress warning such as:
     #  Binding character and factor vector, coercing into character vector
